/*
    Copyright  1995-2001, The AROS Development Team. All rights reserved.
    $Id: isxxxx.c,v 1.1.1.1 2005/03/15 15:56:53 laire Exp $

    Desc: IsXXXX() - Stub for Language isXXXXX() functions.
    Lang: english
*/
#include "locale_intern.h"
#include <aros/asmcall.h>
#include <proto/locale.h>

/*****************************************************************************

    NAME
#include <proto/locale.h>

	AROS_LH2(BOOL, IsXXXX,

    SYNOPSIS
	AROS_LHA(struct Locale *,   locale, A0),
	AROS_LHA(ULONG,             character, D0),

    LOCATION
	struct LocaleBase *, LocaleBase, 0, Locale)

    FUNCTION
	These functions allow you to find out whether a character
	matches a certain type according to the current Locale
	settings.

	The functions available are:

	IsAlNum()  - is this an alphanumeric character
	IsAlpha()  - is this an alphabet character
	IsCntrl()  - is this a control character
	IsDigit()  - is this a decimal digit character
	IsGraph()  - is this a graphical character
	IsLower()  - is this a lowercase character
	IsPrint()  - is this a printable character
	IsPunct()  - is this a punctuation character
	IsSpace()  - is this a whitespace character
	IsUpper()  - is this an uppercase character
	IsXDigit() - is this a hexadecimal digit

    INPUTS
	locale      - The Locale to use for this function.
	character   - the character to test

    RESULT
	ind - An indication of whether the character matches the type.
	    TRUE - if the character is of the required type,
	    FALSE - otherwise

    NOTES
	The Locale MUST be supplied.

	These functions require a 32-bit character to support future
	multi-byte character sets.

    EXAMPLE

    BUGS

    SEE ALSO

    INTERNALS

    HISTORY
	27-11-96    digulla automatically created from
			    locale_lib.fd and clib/locale_protos.h

*****************************************************************************/


AROS_LH2(ULONG, IsAlNum,
    AROS_LHA(struct Locale *, locale, A0),
    AROS_LHA(ULONG          , character, D0),
    struct LocaleBase *, LocaleBase, 14, Locale)
{
    AROS_LIBFUNC_INIT
    AROS_LIBBASE_EXT_DECL(struct LocaleBase *,LocaleBase)

#ifdef AROS_CALL1
    return AROS_CALL1(BOOL, IntL(locale)->il_LanguageFunctions[LF_ISALNUM],
	AROS_LCA(ULONG,    character, D0),
	struct LocaleBase *, LocaleBase);
#else
    return AROS_UFC2(ULONG, IntL(locale)->il_LanguageFunctions[LF_ISALNUM],
	AROS_UFCA(ULONG,    character, D0),
	AROS_UFCA(struct LocaleBase *, LocaleBase, A6));
#endif

    AROS_LIBFUNC_EXIT
} /* IsAlNum */

AROS_LH2(ULONG, IsAlpha,
    AROS_LHA(struct Locale *, locale, A0),
    AROS_LHA(ULONG          , character, D0),
    struct LocaleBase *, LocaleBase, 15, Locale)
{
    AROS_LIBFUNC_INIT
    AROS_LIBBASE_EXT_DECL(struct LocaleBase *,LocaleBase)

#ifdef AROS_CALL1
    return AROS_CALL1(BOOL, IntL(locale)->il_LanguageFunctions[LF_ISALPHA],
	AROS_LCA(ULONG,    character, D0),
	struct LocaleBase *, LocaleBase);
#else
    return AROS_UFC2(ULONG, IntL(locale)->il_LanguageFunctions[LF_ISALPHA],
	AROS_UFCA(ULONG,    character, D0),
	AROS_UFCA(struct LocaleBase *, LocaleBase, A6));
#endif

    AROS_LIBFUNC_EXIT
} /* IsAlpha */

AROS_LH2(ULONG, IsCntrl,
    AROS_LHA(struct Locale *, locale, A0),
    AROS_LHA(ULONG          , character, D0),
    struct LocaleBase *, LocaleBase, 16, Locale)
{
    AROS_LIBFUNC_INIT
    AROS_LIBBASE_EXT_DECL(struct LocaleBase *,LocaleBase)

#ifdef AROS_CALL1
    return AROS_CALL1(BOOL, IntL(locale)->il_LanguageFunctions[LF_ISCNTRL],
	AROS_LCA(ULONG,    character, D0),
	struct LocaleBase *, LocaleBase);
#else
    return AROS_UFC2(ULONG, IntL(locale)->il_LanguageFunctions[LF_ISCNTRL],
	AROS_UFCA(ULONG,    character, D0),
	AROS_UFCA(struct LocaleBase *, LocaleBase, A6));
#endif

    AROS_LIBFUNC_EXIT
} /* IsCntrl */

AROS_LH2(ULONG, IsDigit,
    AROS_LHA(struct Locale *, locale, A0),
    AROS_LHA(ULONG          , character, D0),
    struct LocaleBase *, LocaleBase, 17, Locale)
{
    AROS_LIBFUNC_INIT
    AROS_LIBBASE_EXT_DECL(struct LocaleBase *,LocaleBase)

#ifdef AROS_CALL1
    return AROS_CALL1(BOOL, IntL(locale)->il_LanguageFunctions[LF_ISDIGIT],
	AROS_LCA(ULONG,    character, D0),
	struct LocaleBase *, LocaleBase);
#else
    return AROS_UFC2(ULONG, IntL(locale)->il_LanguageFunctions[LF_ISDIGIT],
	AROS_UFCA(ULONG,    character, D0),
	AROS_UFCA(struct LocaleBase *, LocaleBase, A6));
#endif

    AROS_LIBFUNC_EXIT
} /* IsDigit */

AROS_LH2(ULONG, IsGraph,
    AROS_LHA(struct Locale *, locale, A0),
    AROS_LHA(ULONG          , character, D0),
    struct LocaleBase *, LocaleBase, 18, Locale)
{
    AROS_LIBFUNC_INIT
    AROS_LIBBASE_EXT_DECL(struct LocaleBase *,LocaleBase)

#ifdef AROS_CALL1
    return AROS_CALL1(BOOL, IntL(locale)->il_LanguageFunctions[LF_ISGRAPH],
	AROS_LCA(ULONG,    character, D0),
	struct LocaleBase *, LocaleBase);
#else
    return AROS_UFC2(ULONG, IntL(locale)->il_LanguageFunctions[LF_ISGRAPH],
	AROS_UFCA(ULONG,    character, D0),
	AROS_UFCA(struct LocaleBase *, LocaleBase, A6));
#endif

    AROS_LIBFUNC_EXIT
} /* IsGraph */

AROS_LH2(ULONG, IsLower,
    AROS_LHA(struct Locale *, locale, A0),
    AROS_LHA(ULONG          , character, D0),
    struct LocaleBase *, LocaleBase, 19, Locale)
{
    AROS_LIBFUNC_INIT
    AROS_LIBBASE_EXT_DECL(struct LocaleBase *,LocaleBase)

#ifdef AROS_CALL1
    return AROS_CALL1(BOOL, IntL(locale)->il_LanguageFunctions[LF_ISLOWER],
	AROS_LCA(ULONG,    character, D0),
	struct LocaleBase *, LocaleBase);
#else
    return AROS_UFC2(ULONG, IntL(locale)->il_LanguageFunctions[LF_ISLOWER],
	AROS_UFCA(ULONG,    character, D0),
	AROS_UFCA(struct LocaleBase *, LocaleBase, A6));
#endif

    AROS_LIBFUNC_EXIT
} /* IsLower */

AROS_LH2(ULONG, IsPrint,
    AROS_LHA(struct Locale *, locale, A0),
    AROS_LHA(ULONG          , character, D0),
    struct LocaleBase *, LocaleBase, 20, Locale)
{
    AROS_LIBFUNC_INIT
    AROS_LIBBASE_EXT_DECL(struct LocaleBase *,LocaleBase)

#ifdef AROS_CALL1
    return AROS_CALL1(BOOL, IntL(locale)->il_LanguageFunctions[LF_ISPRINT],
	AROS_LCA(ULONG,    character, D0),
	struct LocaleBase *, LocaleBase);
#else
    return AROS_UFC2(ULONG, IntL(locale)->il_LanguageFunctions[LF_ISPRINT],
	AROS_UFCA(ULONG,    character, D0),
	AROS_UFCA(struct LocaleBase *, LocaleBase, A6));
#endif

    AROS_LIBFUNC_EXIT
} /* IsPrint */

AROS_LH2(ULONG, IsPunct,
    AROS_LHA(struct Locale *, locale, A0),
    AROS_LHA(ULONG          , character, D0),
    struct LocaleBase *, LocaleBase, 21, Locale)
{
    AROS_LIBFUNC_INIT
    AROS_LIBBASE_EXT_DECL(struct LocaleBase *,LocaleBase)

#ifdef AROS_CALL1
    return AROS_CALL1(BOOL, IntL(locale)->il_LanguageFunctions[LF_ISPUNCT],
	AROS_LCA(ULONG,    character, D0),
	struct LocaleBase *, LocaleBase);
#else
    return AROS_UFC2(ULONG, IntL(locale)->il_LanguageFunctions[LF_ISPUNCT],
	AROS_UFCA(ULONG,    character, D0),
	AROS_UFCA(struct LocaleBase *, LocaleBase, A6));
#endif

    AROS_LIBFUNC_EXIT
} /* IsPunct */

AROS_LH2(ULONG, IsSpace,
    AROS_LHA(struct Locale *, locale, A0),
    AROS_LHA(ULONG          , character, D0),
    struct LocaleBase *, LocaleBase, 22, Locale)
{
    AROS_LIBFUNC_INIT
    AROS_LIBBASE_EXT_DECL(struct LocaleBase *,LocaleBase)

#ifdef AROS_CALL1
    return AROS_CALL1(BOOL, IntL(locale)->il_LanguageFunctions[LF_ISSPACE],
	AROS_LCA(ULONG,    character, D0),
	struct LocaleBase *, LocaleBase);
#else
    return AROS_UFC2(ULONG, IntL(locale)->il_LanguageFunctions[LF_ISSPACE],
	AROS_UFCA(ULONG,    character, D0),
	AROS_UFCA(struct LocaleBase *, LocaleBase, A6));
#endif

    AROS_LIBFUNC_EXIT
} /* IsSpace */

AROS_LH2(ULONG, IsUpper,
    AROS_LHA(struct Locale *, locale, A0),
    AROS_LHA(ULONG          , character, D0),
    struct LocaleBase *, LocaleBase, 23, Locale)
{
    AROS_LIBFUNC_INIT
    AROS_LIBBASE_EXT_DECL(struct LocaleBase *,LocaleBase)

#ifdef AROS_CALL1
    return AROS_CALL1(BOOL, IntL(locale)->il_LanguageFunctions[LF_ISUPPER],
	AROS_LCA(ULONG,    character, D0),
	struct LocaleBase *, LocaleBase);
#else
    return AROS_UFC2(ULONG, IntL(locale)->il_LanguageFunctions[LF_ISUPPER],
	AROS_UFCA(ULONG,    character, D0),
	AROS_UFCA(struct LocaleBase *, LocaleBase, A6));
#endif

    AROS_LIBFUNC_EXIT
} /* IsUpper */

AROS_LH2(ULONG, IsXDigit,
    AROS_LHA(struct Locale *, locale, A0),
    AROS_LHA(ULONG          , character, D0),
    struct LocaleBase *, LocaleBase, 24, Locale)
{
    AROS_LIBFUNC_INIT
    AROS_LIBBASE_EXT_DECL(struct LocaleBase *,LocaleBase)

#ifdef AROS_CALL1
    return AROS_CALL1(BOOL, IntL(locale)->il_LanguageFunctions[LF_ISXDIGIT],
	AROS_LCA(ULONG,    character, D0),
	struct LocaleBase *, LocaleBase);
#else
    return AROS_UFC2(ULONG, IntL(locale)->il_LanguageFunctions[LF_ISXDIGIT],
	AROS_UFCA(ULONG,    character, D0),
	AROS_UFCA(struct LocaleBase *, LocaleBase, A6));
#endif

    AROS_LIBFUNC_EXIT
} /* IsXDigit */
