#include <exec/types.h>
#include <proto/exec.h>
#include <proto/dos.h>
#include "locale_intern.h"
#include "private.h"

/* can't really use LocaleBase here */
#undef SysBase
#undef DOSBase
struct ExecBase *SysBase;
struct DosLibrary *DOSBase;

struct SignalSemaphore timezonelock;
timezone_t systemtimezone;
char timezonename[256];

int errno;

void *malloc(size_t size)
{
  void *ptr = AllocVec(size, MEMF_ANY);
  if (!ptr)
    errno = ENOMEM;
  return ptr;
}

void free(void *ptr)
{
  if (ptr)
    FreeVec(ptr);
}

int open(const char *name, int mode)
{
  APTR oldwinptr = (APTR) -1;
  struct Process *self = (APTR) FindTask(NULL);
  BPTR fh;

  if (self->pr_Task.tc_Node.ln_Type == NT_PROCESS)
  {
    oldwinptr = self->pr_WindowPtr;
    self->pr_WindowPtr = (APTR) -1;
  }

  /* first try "SYS:Data/zoneinfo/" */
  fh = memcmp(name, "MOSSYS:", 7) == 0 ? Open(name + 3, MODE_OLDFILE) : 0;
  if (!fh)
  {
    /* if that failed, try "MOSSYS:Data/zoneinfo/" */
    fh = Open(name, MODE_OLDFILE);
  }

  if (self->pr_Task.tc_Node.ln_Type == NT_PROCESS)
    self->pr_WindowPtr = oldwinptr;

  if (fh == 0)
  {
    errno = ENOENT;
    return -1;
  }
  return (int) fh;
}

int close(int fd)
{
  if (fd != -1)
  {
    APTR oldwinptr = (APTR) -1;
    struct Process *self = (APTR) FindTask(NULL);

    if (self->pr_Task.tc_Node.ln_Type == NT_PROCESS)
    {
      oldwinptr = self->pr_WindowPtr;
      self->pr_WindowPtr = (APTR) -1;
    }

    Close((BPTR) fd);

    if (self->pr_Task.tc_Node.ln_Type == NT_PROCESS)
      self->pr_WindowPtr = oldwinptr;
  }
  return 0;
}

int access(const char *name, int mode)
{
  return 0;
}

ssize_t read(int fd, void *buf, size_t count)
{
  ssize_t ret;
  APTR oldwinptr = (APTR) -1;
  struct Process *self = (APTR) FindTask(NULL);

  if (self->pr_Task.tc_Node.ln_Type == NT_PROCESS)
  {
    oldwinptr = self->pr_WindowPtr;
    self->pr_WindowPtr = (APTR) -1;
  }

  ret = Read((BPTR) fd, buf, count);

  if (self->pr_Task.tc_Node.ln_Type == NT_PROCESS)
    self->pr_WindowPtr = oldwinptr;

  if (ret == -1)
    errno = EIO;

  return ret;
}

char *getenv(const char *name)
{
  return NULL;
}

#define SysBase     (((struct IntLocaleBase *)LocaleBase)->lb_SysBase)
#define DOSBase     (((struct IntLocaleBase *)LocaleBase)->lb_DosBase)

LONG TZSetSysTimeZone(CONST_STRPTR tz, struct LocaleBase *LocaleBase)
{
  timezone_t newzone, oldzone;

  size_t l = strlen(tz);
  if (l > sizeof(timezonename) - 1)
  {
    return 0;
  }

  ObtainSemaphore(&timezonelock);

  if (strcmp(timezonename, tz) == 0)
  {
    ReleaseSemaphore(&timezonelock);
    /* No change, return success */
    return 1;
  }

  newzone = tzalloc(tz);

  if (!newzone)
  {
    ReleaseSemaphore(&timezonelock);
    return 0;
  }

  /* preload GMT zoneinfo so that it wouldn't cause potential recursion later on */
  {
    struct tm tmp = {0, 0, 0, 1, 0, 1970 - 1900, 0, 0, 0, 0, 0}; /* jan 1st 1970 00:00:00 */
    if (mktime_z(NULL, &tmp) == ~0)
    {
      ReleaseSemaphore(&timezonelock);
      return 0;
    }
  }

  memcpy(timezonename, tz, l + 1);

  Forbid();
  oldzone = systemtimezone;
  systemtimezone = newzone;
  Permit();

  ReleaseSemaphore(&timezonelock);

  tzfree(oldzone);

  return 1;
}
